@@ -6,7 +6,7 @@ import traceback
 from datetime import datetime
 import pandas as pd
 from typing import Tuple
-import fscloudutils.exceptions as exceptions
+import exceptions
 
 
 class NavRowData:
